@@ -29,6 +29,7 @@ def configs() -> st.SearchStrategy[isort.Config]:
         "known_local_folder",
         "extra_standard_library",
         "forced_separate",
+        "lines_before_imports",
         "lines_after_imports",
         "add_imports",
         "lines_between_sections",
@@ -60,7 +61,7 @@ def configs() -> st.SearchStrategy[isort.Config]:
         "py_version": st.sampled_from(("auto",) + isort.settings.VALID_PY_TARGETS),
     }
     kwargs = {**inferred_kwargs, **specific}
-    return st.fixed_dictionaries({}, optional=kwargs).map(_as_config)
+    return st.fixed_dictionaries({}, optional=kwargs).map(_as_config)  # type:ignore
 
 
 st.register_type_strategy(isort.Config, configs())
@@ -553,10 +554,12 @@ else:  # 2.x
         ),
         default_section="THIRDPARTY",
         import_headings={},
+        import_footers={},
         balanced_wrapping=False,
         use_parentheses=True,
         order_by_type=True,
         atomic=False,
+        lines_before_imports=-1,
         lines_after_imports=-1,
         lines_between_sections=1,
         lines_between_types=0,
@@ -859,10 +862,12 @@ else:  # 2.x
                 "single_line_exclusions": (),
                 "default_section": "THIRDPARTY",
                 "import_headings": {},
+                "import_footers": {},
                 "balanced_wrapping": False,
                 "use_parentheses": False,
                 "order_by_type": True,
                 "atomic": False,
+                "lines_before_imports": -1,
                 "lines_after_imports": -1,
                 "lines_between_sections": 1,
                 "lines_between_types": 0,
@@ -972,7 +977,7 @@ else:  # 2.x
         virtual_env="",
         conda_env="",
         ensure_newline_before_comments=False,
-        directory="/home/abuild/rpmbuild/BUILD/isort-5.5.1",
+        directory="/home/abuild/rpmbuild/BUILD/isort-5.11.0",
         profile="",
         honor_noqa=False,
         old_finders=False,
@@ -1414,10 +1419,12 @@ def test_isort_is_idempotent(config: isort.Config, disregard_skip: bool) -> None
         ),
         default_section="THIRDPARTY",
         import_headings={},
+        import_footers={},
         balanced_wrapping=False,
         use_parentheses=True,
         order_by_type=True,
         atomic=False,
+        lines_before_imports=-1,
         lines_after_imports=-1,
         lines_between_sections=1,
         lines_between_types=0,
@@ -1720,10 +1727,12 @@ def test_isort_is_idempotent(config: isort.Config, disregard_skip: bool) -> None
                 "single_line_exclusions": (),
                 "default_section": "THIRDPARTY",
                 "import_headings": {},
+                "import_footers": {},
                 "balanced_wrapping": False,
                 "use_parentheses": False,
                 "order_by_type": True,
                 "atomic": False,
+                "lines_before_imports": -1,
                 "lines_after_imports": -1,
                 "lines_between_sections": 1,
                 "lines_between_types": 0,
@@ -1833,7 +1842,7 @@ def test_isort_is_idempotent(config: isort.Config, disregard_skip: bool) -> None
         virtual_env="",
         conda_env="",
         ensure_newline_before_comments=False,
-        directory="/home/abuild/rpmbuild/BUILD/isort-5.5.1",
+        directory="/home/abuild/rpmbuild/BUILD/isort-5.11.0",
         profile="",
         honor_noqa=False,
         old_finders=False,
